package com.ynet.life.action;

import com.ynet.gene.comm.tcpip.TCPIPService;
import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.flow.reversal.HostAccessAction;
import com.ynet.gene.format.FormatElement;
import com.ynet.gene.format.GENEFormatException;
import com.ynet.gene.log.GENELog;
import com.ynet.life.base.LifeErrorInfo;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.List;

/* loaded from: com_ynet_life_action.jar:com/ynet/life/action/TCPIPAccessActionSJB.class */
public class TCPIPAccessActionSJB extends HostAccessAction {
    public static final String FIELD_HOST_RETURN_CODE = "hostReturnCode";
    public static final String FIELD_HOST_ERROR_MESSAGE = "hostErrorMessage";
    private static final String ERROR_CODE_PACK = "EBLN0010";
    private static final String ERROR_CODE_POOL = "EBLN0011";
    private static final String ERROR_CODE_LOSEDATA = "EBLN0012";
    private static final String ERROR_CODE_TIMEOUT = "EBLN0013";
    private static final String ERROR_CODE_UNPACK = "EBLN0014";
    private static final String ERROR_CODE_GATEWAY = "EBLN0015";
    private static String TIME_OUT_GATE_MULTY = "58";
    private static String TIME_OUT_MULTY_CORE = "69";
    private static String ENCODING = "UTF-8";
    private String sendFormatName;
    private String receiveFormatName;
    private String identityField;
    private String serviceName;
    public static final boolean MASK_PASSWORD = true;
    public static final String MASK_BEGIN_TAG = "<password>";
    public static final String MASK_END_TAG = "</password>";
    public static final String MASK_CONTENT = "<password>****</password>";
    public static final String FIELD_HOST_DATA_ID = "gatewayData";
    private static final int REQUEST_LENGTH = 10;
    private int timeOut = 5000;
    private boolean throwException = true;

    public void setThrowException(boolean throwException) {
        this.throwException = throwException;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v47 */
    /* JADX WARN: Type inference failed for: r0v80, types: [java.lang.String] */
    public String doExecute(Context context) throws GENEException {
        String receivePackage;
        prepareData(context);
        long beginTime = System.currentTimeMillis();
        try {
            TCPIPService tcpipService = (TCPIPService) context.getService(this.serviceName);
            FormatElement reqfmt = context.getFormat(this.sendFormatName);
            if (reqfmt == null) {
                throw new TranFailException(ERROR_CODE_PACK, "发送报文格式未定义");
            }
            try {
                Object pkg = reqfmt.format(context);
                String gwHead = String.valueOf(getGWHead(context, getReqHeadParams())) + "1";
                byte[] reqMsg = null;
                if (reqfmt.isBin()) {
                    reqMsg = (byte[]) pkg;
                } else {
                    String tmp = String.valueOf(gwHead) + ((String) pkg);
                    String lenStr = "00000000" + String.valueOf(tmp.getBytes().length + 8);
                    String tmp2 = String.valueOf(lenStr.substring(lenStr.length() - REQUEST_LENGTH)) + tmp;
                    if (ENCODING == null) {
                        reqMsg = tmp2.getBytes();
                    } else {
                        try {
                            reqMsg = tmp2.getBytes(ENCODING);
                        } catch (UnsupportedEncodingException unused) {
                        }
                    }
                }
                long beg = System.currentTimeMillis();
                Object identity = null;
                if (this.identityField != null) {
                    identity = context.getDataValue(this.identityField);
                }
                System.out.println("上送报文：" + new String(reqMsg));
                GENELog.log(GENEConstance.GENE_TCPIP, GENELog.INFO, 0, "上送报文" + new String(reqMsg));
                try {
                    byte[] repMsg = tcpipService.sendAndWait(identity, reqMsg, this.timeOut);
                    if (repMsg == null) {
                        Trace.logError("LifeHTTP", "网关通信异常");
                        context.put("GENEException", new GENEException("EL1005", "网关通信异常"));
                        context.put("hostErrorMessage", "网关通信异常");
                        throw new GENEException("EL1005", "网关通信异常");
                    }
                    UnsupportedEncodingException unsupportedEncodingException = 0;
                    String tmpReqMsg = null;
                    try {
                        unsupportedEncodingException = new String(repMsg, ENCODING);
                        tmpReqMsg = unsupportedEncodingException;
                    } catch (UnsupportedEncodingException e) {
                        unsupportedEncodingException.printStackTrace();
                    }
                    String str = tmpReqMsg;
                    String errorCode = str.substring(str.indexOf("<Return_Code>") + 13, tmpReqMsg.indexOf("</Return_Code>"));
                    String str2 = tmpReqMsg;
                    String errorMsg = str2.substring(str2.indexOf("<Return_String>") + 15, tmpReqMsg.indexOf("</Return_String>"));
                    context.put("hostReturnCode", errorCode);
                    context.put("hostErrorMessage", errorMsg);
                    long intvl = System.currentTimeMillis() - beg;
                    GENELog.log(GENEConstance.GENE_TCPIP, GENELog.INFO, 0, "TCPIP Communication [" + getName() + "] takes " + String.valueOf(intvl) + "(ms)");
                    FormatElement repFmt = context.getFormat(this.receiveFormatName);
                    if (repFmt == null) {
                        throw new TranFailException(ERROR_CODE_UNPACK, "未定义返回报文格式");
                    }
                    if (repFmt.isBin()) {
                        try {
                            repFmt.unFormat(repMsg, context);
                        } catch (Exception e2) {
                            Trace.logDebug("LifeHTTP", "解包异常", e2);
                            throw new TranFailException(ERROR_CODE_UNPACK, "解包异常");
                        }
                    } else {
                        if (ENCODING == null) {
                            receivePackage = new String(repMsg);
                        } else {
                            try {
                                receivePackage = new String(repMsg, ENCODING);
                            } catch (UnsupportedEncodingException unused2) {
                                receivePackage = new String(repMsg);
                            }
                        }
                        try {
                            repFmt.unFormat(receivePackage, context);
                            dealResult(context);
                        } catch (Exception e3) {
                            Trace.logDebug("LifeHTTP", "解包异常", e3);
                            throw new TranFailException(ERROR_CODE_UNPACK, "解包异常");
                        }
                    }
                    long timeCost = System.currentTimeMillis() - beginTime;
                    GENELog.log(GENEConstance.GENE_TIME_CONSUMING, GENELog.INFO, 0, "The TCPIPAccessAction:" + getName() + ",times=" + timeCost, (Throwable) null);
                    return "0";
                } catch (Exception e4) {
                    Trace.logError("LifeHTTP", "网关通信异常", e4);
                    context.put("GENEException", e4);
                    context.put("hostErrorMessage", "网关通信异常");
                    throw new GENEException("EL1005", "网关通信异常");
                }
            } catch (GENEFormatException ex) {
                throw new TranFailException(ERROR_CODE_PACK, "发送报文格式化失败", ex);
            }
        } catch (Exception e5) {
            throw new TranFailException(ERROR_CODE_POOL, "无法获取通讯服务", e5);
        }
    }

    private void dealResult(Context context) throws TranFailException {
        int result;
        String hostReturnCode = (String) context.get("hostReturnCode");
        if (hostReturnCode == null) {
            throw new TranFailException("EBLN0000", "无法获取交易结果代码hostReturnCode");
        }
        try {
            result = Integer.parseInt(hostReturnCode);
        } catch (NumberFormatException unused) {
            result = -1;
        }
        if (result != 0) {
            String hostErrorMessage = null;
            try {
                hostErrorMessage = (String) context.getDataValue("hostErrorMessage");
            } catch (GENEException e) {
                print(e.getMessage());
            }
            if (hostErrorMessage == null) {
                LifeErrorInfo error = LifeStandard.getErrorInfo(hostReturnCode);
                if (error == null) {
                    throw new TranFailException(hostReturnCode, "未知的错误代码");
                }
                hostErrorMessage = error.getShowMsg();
            }
            TranFailException ex = new TranFailException(hostReturnCode, hostErrorMessage);
            context.put("GENEException", ex);
            if (this.throwException) {
                throw ex;
            }
        }
    }

    public void setReceiveFormatName(String receiveFormatName) {
        this.receiveFormatName = receiveFormatName;
    }

    public void setSendFormatName(String sendFormatName) {
        this.sendFormatName = sendFormatName;
    }

    public String getSendFormatName() {
        return this.sendFormatName;
    }

    public String getReceiveFormatName() {
        return this.receiveFormatName;
    }

    public void setIdentityField(String identityField) {
        this.identityField = identityField;
    }

    protected void prepareData(Context context) {
        try {
            context.removeDataElement("gatewayData");
        } catch (Exception unused) {
        }
        try {
            KeyedCollection dataKcoll = new KeyedCollection("gatewayData");
            dataKcoll.addDataField("gwReqTime", LifeStandard.getServerTime("yyyyMMddHHmmss"));
            context.addDataElement(dataKcoll);
        } catch (GENEException ex) {
            print(ex.getMessage());
        }
    }

    protected String getGWHead(Context context, List headParams) throws GENEException {
        StringBuffer temp;
        StringBuffer result = new StringBuffer();
        if (headParams != null) {
            for (int i = 0; i < headParams.size(); i++) {
                String param = (String) headParams.get(i);
                boolean isField = param.startsWith("$");
                int idx = param.indexOf(",");
                int len = Integer.parseInt(param.substring(idx + 1).trim());
                if (isField) {
                    temp = new StringBuffer((String) context.getDataValue(param.substring(1, idx)));
                } else {
                    temp = new StringBuffer(param.substring(0, idx));
                }
                if (temp.length() < len) {
                    for (int k = temp.length(); k < len; k++) {
                        temp.append(" ");
                    }
                    result.append(temp);
                } else if (temp.length() > len) {
                    result.append(temp.substring(0, len));
                } else {
                    result.append(temp);
                }
            }
        }
        return result.toString();
    }

    protected List getReqHeadParams() {
        List params = new ArrayList();
        params.add("$gatewayData.gwReqTime,14");
        return params;
    }

    private void print(String message) {
        Trace.logDebug("LifeHTTP", maskMessage(message));
    }

    private String maskMessage(String message) {
        int tagBeginPos = message.indexOf("<password>");
        if (tagBeginPos >= 0) {
            int tagEndPos = message.indexOf("</password>") + 11;
            return String.valueOf(message.substring(0, tagBeginPos)) + "<password>****</password>" + message.substring(tagEndPos);
        }
        return message;
    }

    public String getServiceName() {
        return this.serviceName;
    }

    public void setServiceName(String serviceName) {
        this.serviceName = serviceName;
    }
}
